package com.loopj.android.http;

import java.io.UnsupportedEncodingException;
/* loaded from: classes.dex */
public class Base64 {
    public static final int CRLF = 4;
    public static final int DEFAULT = 0;
    public static final int NO_CLOSE = 16;
    public static final int NO_PADDING = 1;
    public static final int NO_WRAP = 2;
    public static final int URL_SAFE = 8;

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes.dex */
    public static abstract class Coder {
        public int op;
        public byte[] output;

        public abstract int maxOutputSize(int i);

        public abstract boolean process(byte[] bArr, int i, int i2, boolean z);

        Coder() {
        }
    }

    public static byte[] decode(String str, int flags) {
        return decode(str.getBytes(), flags);
    }

    public static byte[] decode(byte[] input, int flags) {
        return decode(input, 0, input.length, flags);
    }

    public static byte[] decode(byte[] input, int offset, int len, int flags) {
        Decoder decoder = new Decoder(flags, new byte[(len * 3) / 4]);
        if (!decoder.process(input, offset, len, true)) {
            throw new IllegalArgumentException("bad base-64");
        }
        if (decoder.op == decoder.output.length) {
            return decoder.output;
        }
        byte[] temp = new byte[decoder.op];
        System.arraycopy(decoder.output, 0, temp, 0, decoder.op);
        return temp;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes.dex */
    public static class Decoder extends Coder {
        private static final int[] DECODE = {-1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, 62, -1, -1, -1, 63, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, -1, -1, -1, -2, -1, -1, -1, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, -1, -1, -1, -1, -1, -1, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1};
        private static final int[] DECODE_WEBSAFE = {-1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, 62, -1, -1, 52, 53, 54, 55, 56, 57, 58, 59, 60, 61, -1, -1, -1, -2, -1, -1, -1, 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, -1, -1, -1, -1, 63, -1, 26, 27, 28, 29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1};
        private static final int EQUALS = -2;
        private static final int SKIP = -1;
        private final int[] alphabet;
        private int state;
        private int value;

        public Decoder(int flags, byte[] output) {
            this.output = output;
            this.alphabet = (flags & 8) == 0 ? DECODE : DECODE_WEBSAFE;
            this.state = 0;
            this.value = 0;
        }

        @Override // com.loopj.android.http.Base64.Coder
        public int maxOutputSize(int len) {
            return ((len * 3) / 4) + 10;
        }

        /* JADX WARN: Code restructure failed: missing block: B:16:0x005d, code lost:
            if (r15 != false) goto L20;
         */
        /* JADX WARN: Code restructure failed: missing block: B:17:0x005f, code lost:
            r11.state = r7;
            r11.value = r8;
            r11.op = r3;
         */
        /* JADX WARN: Code restructure failed: missing block: B:56:0x0102, code lost:
            switch(r7) {
                case 0: goto L24;
                case 1: goto L25;
                case 2: goto L27;
                case 3: goto L28;
                case 4: goto L29;
                default: goto L21;
            };
         */
        /* JADX WARN: Code restructure failed: missing block: B:57:0x0105, code lost:
            r2 = r3;
         */
        /* JADX WARN: Code restructure failed: missing block: B:58:0x0106, code lost:
            r11.state = r7;
            r11.op = r2;
         */
        /* JADX WARN: Code restructure failed: missing block: B:59:0x010d, code lost:
            r2 = r3;
         */
        /* JADX WARN: Code restructure failed: missing block: B:60:0x010f, code lost:
            r11.state = 6;
         */
        /* JADX WARN: Code restructure failed: missing block: B:61:0x0115, code lost:
            r2 = r3 + 1;
            r4[r3] = (byte) (r8 >> 4);
         */
        /* JADX WARN: Code restructure failed: missing block: B:62:0x011d, code lost:
            r2 = r3 + 1;
            r4[r3] = (byte) (r8 >> 10);
            r4[r2] = (byte) (r8 >> 2);
            r2 = r2 + 1;
         */
        /* JADX WARN: Code restructure failed: missing block: B:63:0x012d, code lost:
            r11.state = 6;
         */
        /* JADX WARN: Code restructure failed: missing block: B:89:?, code lost:
            return true;
         */
        /* JADX WARN: Code restructure failed: missing block: B:96:?, code lost:
            return true;
         */
        /* JADX WARN: Code restructure failed: missing block: B:97:?, code lost:
            return false;
         */
        /* JADX WARN: Code restructure failed: missing block: B:98:?, code lost:
            return false;
         */
        @Override // com.loopj.android.http.Base64.Coder
        /*
            Code decompiled incorrectly, please refer to instructions dump.
        */
        public boolean process(byte[] input, int offset, int len, boolean finish) {
            int op;
            if (this.state == 6) {
                return false;
            }
            int p = offset;
            int len2 = len + offset;
            int state = this.state;
            int value = this.value;
            int op2 = 0;
            byte[] output = this.output;
            int[] alphabet = this.alphabet;
            while (true) {
                if (p < len2) {
                    if (state == 0) {
                        while (p + 4 <= len2 && (value = (alphabet[input[p] & 255] << 18) | (alphabet[input[p + 1] & 255] << 12) | (alphabet[input[p + 2] & 255] << 6) | alphabet[input[p + 3] & 255]) >= 0) {
                            output[op2 + 2] = (byte) value;
                            output[op2 + 1] = (byte) (value >> 8);
                            output[op2] = (byte) (value >> 16);
                            op2 += 3;
                            p += 4;
                        }
                        if (p >= len2) {
                            op = op2;
                        }
                    }
                    int p2 = p + 1;
                    int d = alphabet[input[p] & 255];
                    switch (state) {
                        case 0:
                            if (d >= 0) {
                                value = d;
                                state++;
                                break;
                            } else if (d == -1) {
                                break;
                            } else {
                                this.state = 6;
                                return false;
                            }
                        case 1:
                            if (d >= 0) {
                                value = (value << 6) | d;
                                state++;
                                break;
                            } else if (d == -1) {
                                break;
                            } else {
                                this.state = 6;
                                return false;
                            }
                        case 2:
                            if (d >= 0) {
                                value = (value << 6) | d;
                                state++;
                                break;
                            } else if (d == -2) {
                                output[op2] = (byte) (value >> 4);
                                state = 4;
                                op2++;
                                break;
                            } else if (d == -1) {
                                break;
                            } else {
                                this.state = 6;
                                return false;
                            }
                        case 3:
                            if (d >= 0) {
                                value = (value << 6) | d;
                                output[op2 + 2] = (byte) value;
                                output[op2 + 1] = (byte) (value >> 8);
                                output[op2] = (byte) (value >> 16);
                                op2 += 3;
                                state = 0;
                                break;
                            } else if (d == -2) {
                                output[op2 + 1] = (byte) (value >> 2);
                                output[op2] = (byte) (value >> 10);
                                op2 += 2;
                                state = 5;
                                break;
                            } else if (d == -1) {
                                break;
                            } else {
                                this.state = 6;
                                return false;
                            }
                        case 4:
                            if (d == -2) {
                                state++;
                                break;
                            } else if (d == -1) {
                                break;
                            } else {
                                this.state = 6;
                                return false;
                            }
                        case 5:
                            if (d == -1) {
                                break;
                            } else {
                                this.state = 6;
                                return false;
                            }
                    }
                    p = p2;
                } else {
                    op = op2;
                }
            }
        }
    }

    public static String encodeToString(byte[] input, int flags) {
        try {
            return new String(encode(input, flags), "US-ASCII");
        } catch (UnsupportedEncodingException e) {
            throw new AssertionError(e);
        }
    }

    public static String encodeToString(byte[] input, int offset, int len, int flags) {
        try {
            return new String(encode(input, offset, len, flags), "US-ASCII");
        } catch (UnsupportedEncodingException e) {
            throw new AssertionError(e);
        }
    }

    public static byte[] encode(byte[] input, int flags) {
        return encode(input, 0, input.length, flags);
    }

    public static byte[] encode(byte[] input, int offset, int len, int flags) {
        Encoder encoder = new Encoder(flags, null);
        int output_len = (len / 3) * 4;
        if (encoder.do_padding) {
            if (len % 3 > 0) {
                output_len += 4;
            }
        } else {
            switch (len % 3) {
                case 1:
                    output_len += 2;
                    break;
                case 2:
                    output_len += 3;
                    break;
            }
        }
        if (encoder.do_newline && len > 0) {
            output_len += (encoder.do_cr ? 2 : 1) * (((len - 1) / 57) + 1);
        }
        encoder.output = new byte[output_len];
        encoder.process(input, offset, len, true);
        return encoder.output;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    /* loaded from: classes.dex */
    public static class Encoder extends Coder {
        private static final byte[] ENCODE = {65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 43, 47};
        private static final byte[] ENCODE_WEBSAFE = {65, 66, 67, 68, 69, 70, 71, 72, 73, 74, 75, 76, 77, 78, 79, 80, 81, 82, 83, 84, 85, 86, 87, 88, 89, 90, 97, 98, 99, 100, 101, 102, 103, 104, 105, 106, 107, 108, 109, 110, 111, 112, 113, 114, 115, 116, 117, 118, 119, 120, 121, 122, 48, 49, 50, 51, 52, 53, 54, 55, 56, 57, 45, 95};
        public static final int LINE_GROUPS = 19;
        private final byte[] alphabet;
        private int count;
        public final boolean do_cr;
        public final boolean do_newline;
        public final boolean do_padding;
        private final byte[] tail;
        int tailLen;

        public Encoder(int flags, byte[] output) {
            this.output = output;
            this.do_padding = (flags & 1) == 0;
            this.do_newline = (flags & 2) == 0;
            this.do_cr = (flags & 4) != 0;
            this.alphabet = (flags & 8) == 0 ? ENCODE : ENCODE_WEBSAFE;
            this.tail = new byte[2];
            this.tailLen = 0;
            this.count = this.do_newline ? 19 : -1;
        }

        @Override // com.loopj.android.http.Base64.Coder
        public int maxOutputSize(int len) {
            return ((len * 8) / 5) + 10;
        }

        /* JADX WARN: Removed duplicated region for block: B:14:0x0058  */
        /* JADX WARN: Removed duplicated region for block: B:27:0x00fe  */
        /* JADX WARN: Removed duplicated region for block: B:73:0x01f6  */
        /* JADX WARN: Unsupported multi-entry loop pattern (BACK_EDGE: B:81:0x022e -> B:12:0x0052). Please submit an issue!!! */
        @Override // com.loopj.android.http.Base64.Coder
        /*
            Code decompiled incorrectly, please refer to instructions dump.
        */
        public boolean process(byte[] input, int offset, int len, boolean finish) {
            int p;
            int op;
            int op2;
            int op3;
            int p2;
            byte b;
            byte b2;
            int op4;
            byte b3;
            byte[] alphabet = this.alphabet;
            byte[] output = this.output;
            int op5 = 0;
            int count = this.count;
            int p3 = offset;
            int len2 = len + offset;
            int v = -1;
            switch (this.tailLen) {
                case 1:
                    if (p3 + 2 <= len2) {
                        int p4 = p3 + 1;
                        p3 = p4 + 1;
                        v = ((this.tail[0] & 255) << 16) | ((input[p3] & 255) << 8) | (input[p4] & 255);
                        this.tailLen = 0;
                        break;
                    }
                    break;
                case 2:
                    if (p3 + 1 <= len2) {
                        v = ((this.tail[0] & 255) << 16) | ((this.tail[1] & 255) << 8) | (input[p3] & 255);
                        this.tailLen = 0;
                        p3++;
                        break;
                    }
                    break;
            }
            if (v != -1) {
                int op6 = 0 + 1;
                output[0] = alphabet[(v >> 18) & 63];
                int op7 = op6 + 1;
                output[op6] = alphabet[(v >> 12) & 63];
                int op8 = op7 + 1;
                output[op7] = alphabet[(v >> 6) & 63];
                op5 = op8 + 1;
                output[op8] = alphabet[v & 63];
                count--;
                if (count == 0) {
                    if (this.do_cr) {
                        output[op5] = 13;
                        op5++;
                    }
                    op = op5 + 1;
                    output[op5] = 10;
                    count = 19;
                    p = p3;
                    while (p + 3 <= len2) {
                        int v2 = ((input[p] & 255) << 16) | ((input[p + 1] & 255) << 8) | (input[p + 2] & 255);
                        output[op] = alphabet[(v2 >> 18) & 63];
                        output[op + 1] = alphabet[(v2 >> 12) & 63];
                        output[op + 2] = alphabet[(v2 >> 6) & 63];
                        output[op + 3] = alphabet[v2 & 63];
                        p3 = p + 3;
                        op5 = op + 4;
                        count--;
                        if (count == 0) {
                            if (this.do_cr) {
                                output[op5] = 13;
                                op5++;
                            }
                            op = op5 + 1;
                            output[op5] = 10;
                            count = 19;
                            p = p3;
                        }
                    }
                    if (!finish) {
                        if (p - this.tailLen == len2 - 1) {
                            int t = 0;
                            if (this.tailLen > 0) {
                                int t2 = 0 + 1;
                                b3 = this.tail[0];
                                t = t2;
                            } else {
                                int p5 = p + 1;
                                b3 = input[p];
                            }
                            int v3 = (b3 & 255) << 4;
                            this.tailLen -= t;
                            int op9 = op + 1;
                            output[op] = alphabet[(v3 >> 6) & 63];
                            int op10 = op9 + 1;
                            output[op9] = alphabet[v3 & 63];
                            if (this.do_padding) {
                                int op11 = op10 + 1;
                                output[op10] = 61;
                                op10 = op11 + 1;
                                output[op11] = 61;
                            }
                            op2 = op10;
                            if (this.do_newline) {
                                if (this.do_cr) {
                                    output[op2] = 13;
                                    op2++;
                                }
                                op4 = op2 + 1;
                                output[op2] = 10;
                                op2 = op4;
                            }
                        } else if (p - this.tailLen == len2 - 2) {
                            int t3 = 0;
                            if (this.tailLen > 1) {
                                int t4 = 0 + 1;
                                b = this.tail[0];
                                t3 = t4;
                                p2 = p;
                            } else {
                                p2 = p + 1;
                                b = input[p];
                            }
                            int i = (b & 255) << 10;
                            if (this.tailLen > 0) {
                                b2 = this.tail[t3];
                                t3++;
                            } else {
                                int i2 = p2 + 1;
                                b2 = input[p2];
                            }
                            int v4 = i | ((b2 & 255) << 2);
                            this.tailLen -= t3;
                            int op12 = op + 1;
                            output[op] = alphabet[(v4 >> 12) & 63];
                            int op13 = op12 + 1;
                            output[op12] = alphabet[(v4 >> 6) & 63];
                            op2 = op13 + 1;
                            output[op13] = alphabet[v4 & 63];
                            if (this.do_padding) {
                                output[op2] = 61;
                                op2++;
                            }
                            if (this.do_newline) {
                                if (this.do_cr) {
                                    output[op2] = 13;
                                    op2++;
                                }
                                op4 = op2 + 1;
                                output[op2] = 10;
                                op2 = op4;
                            }
                        } else {
                            if (this.do_newline && op > 0 && count != 19) {
                                if (this.do_cr) {
                                    op3 = op + 1;
                                    output[op] = 13;
                                } else {
                                    op3 = op;
                                }
                                output[op3] = 10;
                                op2 = op3 + 1;
                            }
                            op2 = op;
                        }
                    } else if (p == len2 - 1) {
                        byte[] bArr = this.tail;
                        int i3 = this.tailLen;
                        this.tailLen = i3 + 1;
                        bArr[i3] = input[p];
                        op2 = op;
                    } else {
                        if (p == len2 - 2) {
                            byte[] bArr2 = this.tail;
                            int i4 = this.tailLen;
                            this.tailLen = i4 + 1;
                            bArr2[i4] = input[p];
                            byte[] bArr3 = this.tail;
                            int i5 = this.tailLen;
                            this.tailLen = i5 + 1;
                            bArr3[i5] = input[p + 1];
                        }
                        op2 = op;
                    }
                    this.op = op2;
                    this.count = count;
                    return true;
                }
            }
            p = p3;
            op = op5;
            while (p + 3 <= len2) {
            }
            if (!finish) {
            }
            this.op = op2;
            this.count = count;
            return true;
        }
    }

    private Base64() {
    }
}
