package org.cocos2dx.cpp;

import android.media.AudioRecord;
import android.media.MediaRecorder;
import android.util.Log;
import java.io.File;
import java.io.IOException;
import java.io.RandomAccessFile;
/* loaded from: classes.dex */
public class ExtAudioRecorder {
    public static final boolean RECORDING_COMPRESSED = false;
    public static final boolean RECORDING_UNCOMPRESSED = true;
    private static final int TIMER_INTERVAL = 120;
    private int aFormat;
    private int aSource;
    private AudioRecord audioRecorder;
    private short bSamples;
    private byte[] buffer;
    private int bufferSize;
    private int cAmplitude;
    private String filePath;
    private int framePeriod;
    private MediaRecorder mediaRecorder;
    private short nChannels;
    private int payloadSize;
    private boolean rUncompressed;
    private RandomAccessFile randomAccessWriter;
    private int sRate;
    private State state;
    private AudioRecord.OnRecordPositionUpdateListener updateListener = new AudioRecord.OnRecordPositionUpdateListener() { // from class: org.cocos2dx.cpp.ExtAudioRecorder.1
        @Override // android.media.AudioRecord.OnRecordPositionUpdateListener
        public void onPeriodicNotification(AudioRecord recorder) {
            ExtAudioRecorder.this.audioRecorder.read(ExtAudioRecorder.this.buffer, 0, ExtAudioRecorder.this.buffer.length);
            try {
                ExtAudioRecorder.this.randomAccessWriter.write(ExtAudioRecorder.this.buffer);
                ExtAudioRecorder.this.payloadSize += ExtAudioRecorder.this.buffer.length;
                if (ExtAudioRecorder.this.bSamples == 16) {
                    for (int i = 0; i < ExtAudioRecorder.this.buffer.length / 2; i++) {
                        short curSample = ExtAudioRecorder.this.getShort(ExtAudioRecorder.this.buffer[i * 2], ExtAudioRecorder.this.buffer[(i * 2) + 1]);
                        if (curSample > ExtAudioRecorder.this.cAmplitude) {
                            ExtAudioRecorder.this.cAmplitude = curSample;
                        }
                    }
                    return;
                }
                for (int i2 = 0; i2 < ExtAudioRecorder.this.buffer.length; i2++) {
                    if (ExtAudioRecorder.this.buffer[i2] > ExtAudioRecorder.this.cAmplitude) {
                        ExtAudioRecorder.this.cAmplitude = ExtAudioRecorder.this.buffer[i2];
                    }
                }
            } catch (IOException e) {
                Log.e(ExtAudioRecorder.class.getName(), "Error occured in updateListener, recording is aborted");
            }
        }

        @Override // android.media.AudioRecord.OnRecordPositionUpdateListener
        public void onMarkerReached(AudioRecord recorder) {
        }
    };
    private static final int[] sampleRates = {44100, 22050, 11025, 8000};
    private static ExtAudioRecorder result = null;

    /* loaded from: classes.dex */
    public enum State {
        INITIALIZING,
        READY,
        RECORDING,
        ERROR,
        STOPPED
    }

    public static ExtAudioRecorder getInstanse(Boolean recordingCompressed) {
        if (recordingCompressed.booleanValue()) {
            result = new ExtAudioRecorder(false, 1, sampleRates[3], 2, 2);
        } else {
            int i = 3;
            do {
                result = new ExtAudioRecorder(true, 1, sampleRates[i], 2, 2);
                i++;
            } while ((i < sampleRates.length) & (result.getState() != State.INITIALIZING));
        }
        return result;
    }

    public State getState() {
        return this.state;
    }

    public ExtAudioRecorder(boolean uncompressed, int audioSource, int sampleRate, int channelConfig, int audioFormat) {
        this.audioRecorder = null;
        this.mediaRecorder = null;
        this.cAmplitude = 0;
        this.filePath = null;
        try {
            this.rUncompressed = uncompressed;
            if (this.rUncompressed) {
                if (audioFormat == 2) {
                    this.bSamples = (short) 16;
                } else {
                    this.bSamples = (short) 8;
                }
                if (channelConfig == 2) {
                    this.nChannels = (short) 1;
                } else {
                    this.nChannels = (short) 2;
                }
                this.aSource = audioSource;
                this.sRate = sampleRate;
                this.aFormat = audioFormat;
                this.framePeriod = (sampleRate * TIMER_INTERVAL) / 1000;
                this.bufferSize = (((this.framePeriod * 2) * this.bSamples) * this.nChannels) / 8;
                if (this.bufferSize < AudioRecord.getMinBufferSize(sampleRate, channelConfig, audioFormat)) {
                    this.bufferSize = AudioRecord.getMinBufferSize(sampleRate, channelConfig, audioFormat);
                    this.framePeriod = this.bufferSize / (((this.bSamples * 2) * this.nChannels) / 8);
                    Log.w(ExtAudioRecorder.class.getName(), "Increasing buffer size to " + Integer.toString(this.bufferSize));
                }
                this.audioRecorder = new AudioRecord(audioSource, sampleRate, channelConfig, audioFormat, this.bufferSize);
                if (this.audioRecorder.getState() != 1) {
                    throw new Exception("AudioRecord initialization failed");
                }
                this.audioRecorder.setRecordPositionUpdateListener(this.updateListener);
                this.audioRecorder.setPositionNotificationPeriod(this.framePeriod);
            } else {
                this.mediaRecorder = new MediaRecorder();
                this.mediaRecorder.setAudioSource(1);
                this.mediaRecorder.setOutputFormat(1);
                this.mediaRecorder.setAudioEncoder(1);
            }
            this.cAmplitude = 0;
            this.filePath = null;
            this.state = State.INITIALIZING;
        } catch (Exception e) {
            if (e.getMessage() != null) {
                Log.e(ExtAudioRecorder.class.getName(), e.getMessage());
            } else {
                Log.e(ExtAudioRecorder.class.getName(), "Unknown error occured while initializing recording");
            }
            this.state = State.ERROR;
        }
    }

    public void setOutputFile(String argPath) {
        try {
            if (this.state == State.INITIALIZING) {
                this.filePath = argPath;
                if (!this.rUncompressed) {
                    this.mediaRecorder.setOutputFile(this.filePath);
                }
            }
        } catch (Exception e) {
            if (e.getMessage() != null) {
                Log.e(ExtAudioRecorder.class.getName(), e.getMessage());
            } else {
                Log.e(ExtAudioRecorder.class.getName(), "Unknown error occured while setting output path");
            }
            this.state = State.ERROR;
        }
    }

    public int getMaxAmplitude() {
        if (this.state == State.RECORDING) {
            if (this.rUncompressed) {
                int result2 = this.cAmplitude;
                this.cAmplitude = 0;
                return result2;
            }
            try {
                int result3 = this.mediaRecorder.getMaxAmplitude();
                return result3;
            } catch (IllegalStateException e) {
                return 0;
            }
        }
        return 0;
    }

    public void prepare() {
        try {
            if (this.state == State.INITIALIZING) {
                if (this.rUncompressed) {
                    if ((this.filePath != null) & (this.audioRecorder.getState() == 1)) {
                        this.randomAccessWriter = new RandomAccessFile(this.filePath, "rw");
                        this.randomAccessWriter.setLength(0L);
                        this.randomAccessWriter.writeBytes("RIFF");
                        this.randomAccessWriter.writeInt(0);
                        this.randomAccessWriter.writeBytes("WAVE");
                        this.randomAccessWriter.writeBytes("fmt ");
                        this.randomAccessWriter.writeInt(Integer.reverseBytes(16));
                        this.randomAccessWriter.writeShort(Short.reverseBytes((short) 1));
                        this.randomAccessWriter.writeShort(Short.reverseBytes(this.nChannels));
                        this.randomAccessWriter.writeInt(Integer.reverseBytes(this.sRate));
                        this.randomAccessWriter.writeInt(Integer.reverseBytes(((this.sRate * this.bSamples) * this.nChannels) / 8));
                        this.randomAccessWriter.writeShort(Short.reverseBytes((short) ((this.nChannels * this.bSamples) / 8)));
                        this.randomAccessWriter.writeShort(Short.reverseBytes(this.bSamples));
                        this.randomAccessWriter.writeBytes("data");
                        this.randomAccessWriter.writeInt(0);
                        this.buffer = new byte[((this.framePeriod * this.bSamples) / 8) * this.nChannels];
                        this.state = State.READY;
                    } else {
                        Log.e(ExtAudioRecorder.class.getName(), "prepare() method called on uninitialized recorder");
                        this.state = State.ERROR;
                    }
                } else {
                    this.mediaRecorder.prepare();
                    this.state = State.READY;
                }
            } else {
                Log.e(ExtAudioRecorder.class.getName(), "prepare() method called on illegal state");
                release();
                this.state = State.ERROR;
            }
        } catch (Exception e) {
            if (e.getMessage() != null) {
                Log.e(ExtAudioRecorder.class.getName(), e.getMessage());
            } else {
                Log.e(ExtAudioRecorder.class.getName(), "Unknown error occured in prepare()");
            }
            this.state = State.ERROR;
        }
    }

    public void release() {
        if (this.state == State.RECORDING) {
            stop();
        } else {
            if ((this.state == State.READY) & this.rUncompressed) {
                try {
                    this.randomAccessWriter.close();
                } catch (IOException e) {
                    Log.e(ExtAudioRecorder.class.getName(), "I/O exception occured while closing output file");
                }
                new File(this.filePath).delete();
            }
        }
        if (this.rUncompressed) {
            if (this.audioRecorder != null) {
                this.audioRecorder.release();
            }
        } else if (this.mediaRecorder != null) {
            this.mediaRecorder.release();
        }
    }

    public void reset() {
        try {
            if (this.state != State.ERROR) {
                release();
                this.filePath = null;
                this.cAmplitude = 0;
                if (this.rUncompressed) {
                    this.audioRecorder = new AudioRecord(this.aSource, this.sRate, this.nChannels + 1, this.aFormat, this.bufferSize);
                } else {
                    this.mediaRecorder = new MediaRecorder();
                    this.mediaRecorder.setAudioSource(1);
                    this.mediaRecorder.setOutputFormat(1);
                    this.mediaRecorder.setAudioEncoder(1);
                }
                this.state = State.INITIALIZING;
            }
        } catch (Exception e) {
            Log.e(ExtAudioRecorder.class.getName(), e.getMessage());
            this.state = State.ERROR;
        }
    }

    public void start() {
        if (this.state == State.READY) {
            if (this.rUncompressed) {
                this.payloadSize = 0;
                this.audioRecorder.startRecording();
                this.audioRecorder.read(this.buffer, 0, this.buffer.length);
            } else {
                this.mediaRecorder.start();
            }
            this.state = State.RECORDING;
            return;
        }
        Log.e(ExtAudioRecorder.class.getName(), "start() called on illegal state");
        this.state = State.ERROR;
    }

    public void stop() {
        if (this.state == State.RECORDING) {
            if (this.rUncompressed) {
                this.audioRecorder.stop();
                try {
                    this.randomAccessWriter.seek(4L);
                    this.randomAccessWriter.writeInt(Integer.reverseBytes(this.payloadSize + 36));
                    this.randomAccessWriter.seek(40L);
                    this.randomAccessWriter.writeInt(Integer.reverseBytes(this.payloadSize));
                    this.randomAccessWriter.close();
                } catch (IOException e) {
                    Log.e(ExtAudioRecorder.class.getName(), "I/O exception occured while closing output file");
                    this.state = State.ERROR;
                }
            } else {
                this.mediaRecorder.stop();
            }
            this.state = State.STOPPED;
            return;
        }
        Log.e(ExtAudioRecorder.class.getName(), "stop() called on illegal state");
        this.state = State.ERROR;
    }

    /* JADX INFO: Access modifiers changed from: private */
    public short getShort(byte argB1, byte argB2) {
        return (short) ((argB2 << 8) | argB1);
    }

    public static File recordChat(String savePath, String fileName) {
        File dir = new File(savePath);
        if (dir.list() == null) {
            dir.mkdirs();
        }
        File file = new File(savePath + fileName);
        result.setOutputFile(savePath + fileName);
        result.prepare();
        result.start();
        return file;
    }

    public static String stopRecord() {
        result.stop();
        result.release();
        Log.d("stopRecord", result.filePath);
        return result.filePath;
    }
}
